==> cdi-tck-impl-1.1.0.Final-sources.jar: org/jboss/cdi/tck/tests/implementation/builtin/metadata/broken/typeparam/decorator/DecoratorTypeParamInitializerTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.implementation.builtin.metadata.broken.typeparam.decorator;

import static org.jboss.cdi.tck.cdi.Sections.BEAN_METADATA;

import javax.enterprise.inject.spi.DefinitionException;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.ShouldThrowException;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.cdi.tck.tests.implementation.builtin.metadata.broken.typeparam.Cream;
import org.jboss.cdi.tck.tests.implementation.builtin.metadata.broken.typeparam.Milk;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * @author Martin Kouba
 * 
 */
@SpecVersion(spec = "cdi", version = "20091101")
public class DecoratorTypeParamInitializerTest extends AbstractTest {

    @ShouldThrowException(DefinitionException.class)
    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassDefinition(DecoratorTypeParamInitializerTest.class)
                .withClasses(Cream.class, MilkDecoratorInitializer.class, Milk.class).build();
    }

    @Test
    @SpecAssertion(section = BEAN_METADATA, id = "l")
    public void testDeploymentFails() {
    }

}

==> cdi-tck-impl-1.2.3.Final-sources.jar: org/jboss/cdi/tck/tests/implementation/builtin/metadata/broken/typeparam/decorator/DecoratorTypeParamInitializerTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.implementation.builtin.metadata.broken.typeparam.decorator;

import static org.jboss.cdi.tck.cdi.Sections.BEAN_METADATA;

import javax.enterprise.inject.spi.DefinitionException;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.ShouldThrowException;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.cdi.tck.tests.implementation.builtin.metadata.broken.typeparam.Cream;
import org.jboss.cdi.tck.tests.implementation.builtin.metadata.broken.typeparam.Milk;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

/**
 * @author Martin Kouba
 * 
 */
@SpecVersion(spec = "cdi", version = "1.1 Final Release")
public class DecoratorTypeParamInitializerTest extends AbstractTest {

    @ShouldThrowException(DefinitionException.class)
    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassDefinition(DecoratorTypeParamInitializerTest.class)
                .withClasses(Cream.class, MilkDecoratorInitializer.class, Milk.class).build();
    }

    @Test
    @SpecAssertion(section = BEAN_METADATA, id = "l")
    public void testDeploymentFails() {
    }

}
